openerp.odoo_management = function(instance, local) {

    local.ConfigPage = instance.Widget.extend({
        template: 'ConfigTemplate',
        data: {
            docker_socket_path: '',
            docker_exclusion_list: [],
            odoo_docker_image: '',
            odoo_network: '',
            odoo_ports_range: [],
            odoo_root_path: '',
            odoo_db_link: '',
            modules_git_path: ''
        },
        events: {
            'click .oe_button': 'send_config'
        },
        start: function() {
            this.$exclusions = this.$('#exclusions-input');
            this.$odooImage = this.$('#image-input');
            this.$odooNetwork = this.$('#network-input');
            this.$odooDb = this.$('#db-input');

            this.prepare_inputs();
            this.get_config();
        },
        configure_tags_input: function($input, plugins, tags, cb) {
            $input.textext({
                plugins: plugins,
                tagsItems: tags,
                ext: {
                    autocomplete: {
                        selectFromDropdown: function() {
                            var suggestion = this.selectedSuggestionElement().data('text-suggestion');
                            
                            if (suggestion) {
                                this.val(this.itemManager().itemToString(suggestion));
                                this.core().getFormData();
                                
                                cb(suggestion);
                            }
    
                            this.trigger('hideDropdown');
                        }
                    }
                }
            });
        },
        prepare_inputs: function() {
            var _this = this;
            
            this.configure_tags_input(this.$exclusions, 'tags arrow autocomplete', [], function(suggestion) {
                _this.data.docker_exclusion_list.push(suggestion);
            });

            this.configure_tags_input(this.$odooImage, 'autocomplete arrow', [], function(suggestion) {
                _this.data.odoo_docker_image = suggestion;
            });

            this.configure_tags_input(this.$odooNetwork, 'autocomplete arrow', [], function(suggestion) {
                _this.data.odoo_network = suggestion;
            });

            this.configure_tags_input(this.$odooDb, 'autocomplete arrow', [], function(suggestion) {
                _this.data.odoo_db_link = suggestion;
            });
        },
        prepare_suggestions: function(collection, filter) {
            return function(e, data) {
                var suggestions = _.map(collection, function(item) {
                    return item.name;
                });

                var textext = $(e.target).textext()[0];
                var query = (data ? data.query : '') || '';

                $(this).trigger('setSuggestions', {
                    result: !!filter ? textext.itemManager().filter(suggestions, query) : suggestions
                });
            }
        },
        initialize_inputs: function() {
            this.$exclusions.bind('getSuggestions', this.prepare_suggestions(this.config.containers, true));
            this.$odooImage.bind('getSuggestions', this.prepare_suggestions(this.config.images));
            this.$odooNetwork.bind('getSuggestions', this.prepare_suggestions(this.config.networks));
            this.$odooDb.bind('getSuggestions', this.prepare_suggestions(this.config.images));
        },
        set_initial_data: function() {
            this.$exclusions.textext()[0].tags().addTags(this.config.docker_exclusion_list);
            this.$(this.$odooImage).val(this.config.odoo_docker_image);
            this.$(this.$odooNetwork).val(this.config.odoo_network);
            this.$(this.$odooDb).val(this.config.odoo_db_link);

            this.$('#socket-input').val(this.config.docker_socket_path);
            this.$('#ports-range-input').val(this.config.odoo_ports_range);
            this.$('#odoo-path-input').val(this.config.odoo_root_path);
            this.$('#git-path-input').val(this.config.modules_git_path);
        },
        get_config: function() {
            var _this = this;

            this.rpc('/odoo_management/get_config').done(function(config) {
                _this.config = config;
                _this.initialize_inputs();
                _this.set_initial_data();
            });  
        },
        send_config: function() {
            _.extend(this.data, {
                docker_socket_path: this.$('#socket-input').val(),
                odoo_ports_range: this.$('#ports-range-input').val(),
                odoo_root_path: this.$('#odoo-path-input').val(),
                modules_git_path: this.$('#git-path-input').val()
            });

            this.rpc('/odoo_management/save_config', this.data).done(function(data) {
                console.log(data);
            }); 
        }
    });

    instance.web.client_actions.add('odoo_management.configuration', 'instance.odoo_management.ConfigPage');
}
